"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6913 import (
        AbstractAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6914 import (
        AbstractShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6915 import (
        AbstractShaftOrHousingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6916 import (
        AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6917 import (
        AGMAGleasonConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6918 import (
        AGMAGleasonConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6919 import (
        AGMAGleasonConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6920 import (
        AssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6921 import (
        BearingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6922 import (
        BeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6923 import (
        BeltDriveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6924 import (
        BevelDifferentialGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6925 import (
        BevelDifferentialGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6926 import (
        BevelDifferentialGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6927 import (
        BevelDifferentialPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6928 import (
        BevelDifferentialSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6929 import (
        BevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6930 import (
        BevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6931 import (
        BevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6932 import (
        BoltCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6933 import (
        BoltedJointCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6934 import (
        ClutchConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6935 import (
        ClutchCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6936 import (
        ClutchHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6937 import (
        CoaxialConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6938 import (
        ComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6939 import (
        ConceptCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6940 import (
        ConceptCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6941 import (
        ConceptCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6942 import (
        ConceptGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6943 import (
        ConceptGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6944 import (
        ConceptGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6945 import (
        ConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6946 import (
        ConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6947 import (
        ConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6948 import (
        ConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6949 import (
        ConnectorCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6950 import (
        CouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6951 import (
        CouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6952 import (
        CouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6953 import (
        CriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6954 import (
        CriticalSpeedAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6955 import (
        CriticalSpeedAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6956 import (
        CVTBeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6957 import (
        CVTCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6958 import (
        CVTPulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6959 import (
        CycloidalAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6960 import (
        CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6961 import (
        CycloidalDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6962 import (
        CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6963 import (
        CylindricalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6964 import (
        CylindricalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6965 import (
        CylindricalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6966 import (
        CylindricalPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6967 import (
        DatumCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6968 import (
        ExternalCADModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6969 import (
        FaceGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6970 import (
        FaceGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6971 import (
        FaceGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6972 import (
        FEPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6973 import (
        FlexiblePinAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6974 import (
        GearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6975 import (
        GearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6976 import (
        GearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6977 import (
        GuideDxfModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6978 import (
        HypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6979 import (
        HypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6980 import (
        HypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6981 import (
        InterMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6982 import (
        KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6983 import (
        KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6984 import (
        KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6985 import (
        KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6986 import (
        KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6987 import (
        KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6988 import (
        KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6989 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6990 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6991 import (
        MassDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6992 import (
        MeasurementComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6993 import (
        MicrophoneArrayCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6994 import (
        MicrophoneCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6995 import (
        MountableComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6996 import (
        OilSealCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6997 import (
        PartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6998 import (
        PartToPartShearCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6999 import (
        PartToPartShearCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7000 import (
        PartToPartShearCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7001 import (
        PlanetaryConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7002 import (
        PlanetaryGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7003 import (
        PlanetCarrierCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7004 import (
        PointLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7005 import (
        PowerLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7006 import (
        PulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7007 import (
        RingPinsCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7008 import (
        RingPinsToDiscConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7009 import (
        RollingRingAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7010 import (
        RollingRingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7011 import (
        RollingRingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7012 import (
        RootAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7013 import (
        ShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7014 import (
        ShaftHubConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7015 import (
        ShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7016 import (
        SpecialisedAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7017 import (
        SpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7018 import (
        SpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7019 import (
        SpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7020 import (
        SpringDamperConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7021 import (
        SpringDamperCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7022 import (
        SpringDamperHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7023 import (
        StraightBevelDiffGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7024 import (
        StraightBevelDiffGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7025 import (
        StraightBevelDiffGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7026 import (
        StraightBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7027 import (
        StraightBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7028 import (
        StraightBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7029 import (
        StraightBevelPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7030 import (
        StraightBevelSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7031 import (
        SynchroniserCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7032 import (
        SynchroniserHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7033 import (
        SynchroniserPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7034 import (
        SynchroniserSleeveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7035 import (
        TorqueConverterConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7036 import (
        TorqueConverterCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7037 import (
        TorqueConverterPumpCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7038 import (
        TorqueConverterTurbineCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7039 import (
        UnbalancedMassCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7040 import (
        VirtualComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7041 import (
        WormGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7042 import (
        WormGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7043 import (
        WormGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7044 import (
        ZerolBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7045 import (
        ZerolBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._7046 import (
        ZerolBevelGearSetCriticalSpeedAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.critical_speed_analyses._6913": [
            "AbstractAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6914": [
            "AbstractShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6915": [
            "AbstractShaftOrHousingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6916": [
            "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6917": [
            "AGMAGleasonConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6918": [
            "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6919": [
            "AGMAGleasonConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6920": [
            "AssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6921": [
            "BearingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6922": [
            "BeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6923": [
            "BeltDriveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6924": [
            "BevelDifferentialGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6925": [
            "BevelDifferentialGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6926": [
            "BevelDifferentialGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6927": [
            "BevelDifferentialPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6928": [
            "BevelDifferentialSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6929": [
            "BevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6930": [
            "BevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6931": [
            "BevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6932": [
            "BoltCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6933": [
            "BoltedJointCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6934": [
            "ClutchConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6935": [
            "ClutchCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6936": [
            "ClutchHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6937": [
            "CoaxialConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6938": [
            "ComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6939": [
            "ConceptCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6940": [
            "ConceptCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6941": [
            "ConceptCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6942": [
            "ConceptGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6943": [
            "ConceptGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6944": [
            "ConceptGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6945": [
            "ConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6946": [
            "ConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6947": [
            "ConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6948": [
            "ConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6949": [
            "ConnectorCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6950": [
            "CouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6951": [
            "CouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6952": [
            "CouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6953": [
            "CriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6954": [
            "CriticalSpeedAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6955": [
            "CriticalSpeedAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6956": [
            "CVTBeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6957": [
            "CVTCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6958": [
            "CVTPulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6959": [
            "CycloidalAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6960": [
            "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6961": [
            "CycloidalDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6962": [
            "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6963": [
            "CylindricalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6964": [
            "CylindricalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6965": [
            "CylindricalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6966": [
            "CylindricalPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6967": [
            "DatumCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6968": [
            "ExternalCADModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6969": [
            "FaceGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6970": [
            "FaceGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6971": [
            "FaceGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6972": [
            "FEPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6973": [
            "FlexiblePinAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6974": [
            "GearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6975": [
            "GearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6976": [
            "GearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6977": [
            "GuideDxfModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6978": [
            "HypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6979": [
            "HypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6980": [
            "HypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6981": [
            "InterMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6982": [
            "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6983": [
            "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6984": [
            "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6985": [
            "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6986": [
            "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6987": [
            "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6988": [
            "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6989": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6990": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6991": [
            "MassDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6992": [
            "MeasurementComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6993": [
            "MicrophoneArrayCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6994": [
            "MicrophoneCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6995": [
            "MountableComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6996": [
            "OilSealCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6997": [
            "PartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6998": [
            "PartToPartShearCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6999": [
            "PartToPartShearCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7000": [
            "PartToPartShearCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7001": [
            "PlanetaryConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7002": [
            "PlanetaryGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7003": [
            "PlanetCarrierCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7004": [
            "PointLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7005": [
            "PowerLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7006": [
            "PulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7007": [
            "RingPinsCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7008": [
            "RingPinsToDiscConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7009": [
            "RollingRingAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7010": [
            "RollingRingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7011": [
            "RollingRingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7012": [
            "RootAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7013": [
            "ShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7014": [
            "ShaftHubConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7015": [
            "ShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7016": [
            "SpecialisedAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7017": [
            "SpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7018": [
            "SpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7019": [
            "SpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7020": [
            "SpringDamperConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7021": [
            "SpringDamperCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7022": [
            "SpringDamperHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7023": [
            "StraightBevelDiffGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7024": [
            "StraightBevelDiffGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7025": [
            "StraightBevelDiffGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7026": [
            "StraightBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7027": [
            "StraightBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7028": [
            "StraightBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7029": [
            "StraightBevelPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7030": [
            "StraightBevelSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7031": [
            "SynchroniserCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7032": [
            "SynchroniserHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7033": [
            "SynchroniserPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7034": [
            "SynchroniserSleeveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7035": [
            "TorqueConverterConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7036": [
            "TorqueConverterCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7037": [
            "TorqueConverterPumpCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7038": [
            "TorqueConverterTurbineCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7039": [
            "UnbalancedMassCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7040": [
            "VirtualComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7041": [
            "WormGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7042": [
            "WormGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7043": [
            "WormGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7044": [
            "ZerolBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7045": [
            "ZerolBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._7046": [
            "ZerolBevelGearSetCriticalSpeedAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCriticalSpeedAnalysis",
    "AbstractShaftCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCriticalSpeedAnalysis",
    "AssemblyCriticalSpeedAnalysis",
    "BearingCriticalSpeedAnalysis",
    "BeltConnectionCriticalSpeedAnalysis",
    "BeltDriveCriticalSpeedAnalysis",
    "BevelDifferentialGearCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCriticalSpeedAnalysis",
    "BevelGearCriticalSpeedAnalysis",
    "BevelGearMeshCriticalSpeedAnalysis",
    "BevelGearSetCriticalSpeedAnalysis",
    "BoltCriticalSpeedAnalysis",
    "BoltedJointCriticalSpeedAnalysis",
    "ClutchConnectionCriticalSpeedAnalysis",
    "ClutchCriticalSpeedAnalysis",
    "ClutchHalfCriticalSpeedAnalysis",
    "CoaxialConnectionCriticalSpeedAnalysis",
    "ComponentCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCriticalSpeedAnalysis",
    "ConceptCouplingCriticalSpeedAnalysis",
    "ConceptCouplingHalfCriticalSpeedAnalysis",
    "ConceptGearCriticalSpeedAnalysis",
    "ConceptGearMeshCriticalSpeedAnalysis",
    "ConceptGearSetCriticalSpeedAnalysis",
    "ConicalGearCriticalSpeedAnalysis",
    "ConicalGearMeshCriticalSpeedAnalysis",
    "ConicalGearSetCriticalSpeedAnalysis",
    "ConnectionCriticalSpeedAnalysis",
    "ConnectorCriticalSpeedAnalysis",
    "CouplingConnectionCriticalSpeedAnalysis",
    "CouplingCriticalSpeedAnalysis",
    "CouplingHalfCriticalSpeedAnalysis",
    "CriticalSpeedAnalysis",
    "CriticalSpeedAnalysisDrawStyle",
    "CriticalSpeedAnalysisOptions",
    "CVTBeltConnectionCriticalSpeedAnalysis",
    "CVTCriticalSpeedAnalysis",
    "CVTPulleyCriticalSpeedAnalysis",
    "CycloidalAssemblyCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis",
    "CycloidalDiscCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis",
    "CylindricalGearCriticalSpeedAnalysis",
    "CylindricalGearMeshCriticalSpeedAnalysis",
    "CylindricalGearSetCriticalSpeedAnalysis",
    "CylindricalPlanetGearCriticalSpeedAnalysis",
    "DatumCriticalSpeedAnalysis",
    "ExternalCADModelCriticalSpeedAnalysis",
    "FaceGearCriticalSpeedAnalysis",
    "FaceGearMeshCriticalSpeedAnalysis",
    "FaceGearSetCriticalSpeedAnalysis",
    "FEPartCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCriticalSpeedAnalysis",
    "GearCriticalSpeedAnalysis",
    "GearMeshCriticalSpeedAnalysis",
    "GearSetCriticalSpeedAnalysis",
    "GuideDxfModelCriticalSpeedAnalysis",
    "HypoidGearCriticalSpeedAnalysis",
    "HypoidGearMeshCriticalSpeedAnalysis",
    "HypoidGearSetCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis",
    "MassDiscCriticalSpeedAnalysis",
    "MeasurementComponentCriticalSpeedAnalysis",
    "MicrophoneArrayCriticalSpeedAnalysis",
    "MicrophoneCriticalSpeedAnalysis",
    "MountableComponentCriticalSpeedAnalysis",
    "OilSealCriticalSpeedAnalysis",
    "PartCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCriticalSpeedAnalysis",
    "PartToPartShearCouplingCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCriticalSpeedAnalysis",
    "PlanetaryConnectionCriticalSpeedAnalysis",
    "PlanetaryGearSetCriticalSpeedAnalysis",
    "PlanetCarrierCriticalSpeedAnalysis",
    "PointLoadCriticalSpeedAnalysis",
    "PowerLoadCriticalSpeedAnalysis",
    "PulleyCriticalSpeedAnalysis",
    "RingPinsCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCriticalSpeedAnalysis",
    "RollingRingAssemblyCriticalSpeedAnalysis",
    "RollingRingConnectionCriticalSpeedAnalysis",
    "RollingRingCriticalSpeedAnalysis",
    "RootAssemblyCriticalSpeedAnalysis",
    "ShaftCriticalSpeedAnalysis",
    "ShaftHubConnectionCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "SpecialisedAssemblyCriticalSpeedAnalysis",
    "SpiralBevelGearCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCriticalSpeedAnalysis",
    "SpiralBevelGearSetCriticalSpeedAnalysis",
    "SpringDamperConnectionCriticalSpeedAnalysis",
    "SpringDamperCriticalSpeedAnalysis",
    "SpringDamperHalfCriticalSpeedAnalysis",
    "StraightBevelDiffGearCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCriticalSpeedAnalysis",
    "StraightBevelGearCriticalSpeedAnalysis",
    "StraightBevelGearMeshCriticalSpeedAnalysis",
    "StraightBevelGearSetCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCriticalSpeedAnalysis",
    "StraightBevelSunGearCriticalSpeedAnalysis",
    "SynchroniserCriticalSpeedAnalysis",
    "SynchroniserHalfCriticalSpeedAnalysis",
    "SynchroniserPartCriticalSpeedAnalysis",
    "SynchroniserSleeveCriticalSpeedAnalysis",
    "TorqueConverterConnectionCriticalSpeedAnalysis",
    "TorqueConverterCriticalSpeedAnalysis",
    "TorqueConverterPumpCriticalSpeedAnalysis",
    "TorqueConverterTurbineCriticalSpeedAnalysis",
    "UnbalancedMassCriticalSpeedAnalysis",
    "VirtualComponentCriticalSpeedAnalysis",
    "WormGearCriticalSpeedAnalysis",
    "WormGearMeshCriticalSpeedAnalysis",
    "WormGearSetCriticalSpeedAnalysis",
    "ZerolBevelGearCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCriticalSpeedAnalysis",
    "ZerolBevelGearSetCriticalSpeedAnalysis",
)



"""BevelHypoidGearRatingSettingsItem"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.utility.databases import _2063

_BEVEL_HYPOID_GEAR_RATING_SETTINGS_ITEM = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns", "BevelHypoidGearRatingSettingsItem"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.materials import _730
    from mastapy._private.gears.rating.hypoid import _554
    from mastapy._private.gears.rating.iso_10300 import _533, _541, _548

    Self = TypeVar("Self", bound="BevelHypoidGearRatingSettingsItem")
    CastSelf = TypeVar(
        "CastSelf",
        bound="BevelHypoidGearRatingSettingsItem._Cast_BevelHypoidGearRatingSettingsItem",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BevelHypoidGearRatingSettingsItem",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BevelHypoidGearRatingSettingsItem:
    """Special nested class for casting BevelHypoidGearRatingSettingsItem to subclasses."""

    __parent__: "BevelHypoidGearRatingSettingsItem"

    @property
    def named_database_item(self: "CastSelf") -> "_2063.NamedDatabaseItem":
        return self.__parent__._cast(_2063.NamedDatabaseItem)

    @property
    def bevel_hypoid_gear_rating_settings_item(
        self: "CastSelf",
    ) -> "BevelHypoidGearRatingSettingsItem":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BevelHypoidGearRatingSettingsItem(_2063.NamedDatabaseItem):
    """BevelHypoidGearRatingSettingsItem

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEVEL_HYPOID_GEAR_RATING_SETTINGS_ITEM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bevel_gear_rating_method(self: "Self") -> "_730.RatingMethods":
        """mastapy.gears.materials.RatingMethods"""
        temp = pythonnet_property_get(self.wrapped, "BevelGearRatingMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Materials.RatingMethods"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.materials._730", "RatingMethods"
        )(value)

    @bevel_gear_rating_method.setter
    @exception_bridge
    @enforce_parameter_types
    def bevel_gear_rating_method(self: "Self", value: "_730.RatingMethods") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Materials.RatingMethods"
        )
        pythonnet_property_set(self.wrapped, "BevelGearRatingMethod", value)

    @property
    @exception_bridge
    def bevel_general_load_factors_k_method(
        self: "Self",
    ) -> "_533.GeneralLoadFactorCalculationMethod":
        """mastapy.gears.rating.isoGeneralLoadFactorCalculationMethod"""
        temp = pythonnet_property_get(self.wrapped, "BevelGeneralLoadFactorsKMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Iso10300.GeneralLoadFactorCalculationMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._533", "GeneralLoadFactorCalculationMethod"
        )(value)

    @bevel_general_load_factors_k_method.setter
    @exception_bridge
    @enforce_parameter_types
    def bevel_general_load_factors_k_method(
        self: "Self", value: "_533.GeneralLoadFactorCalculationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.Rating.Iso10300.GeneralLoadFactorCalculationMethod",
        )
        pythonnet_property_set(self.wrapped, "BevelGeneralLoadFactorsKMethod", value)

    @property
    @exception_bridge
    def bevel_pitting_factor_calculation_method(
        self: "Self",
    ) -> "_548.PittingFactorCalculationMethod":
        """mastapy.gears.rating.isoPittingFactorCalculationMethod"""
        temp = pythonnet_property_get(
            self.wrapped, "BevelPittingFactorCalculationMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Iso10300.PittingFactorCalculationMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._548", "PittingFactorCalculationMethod"
        )(value)

    @bevel_pitting_factor_calculation_method.setter
    @exception_bridge
    @enforce_parameter_types
    def bevel_pitting_factor_calculation_method(
        self: "Self", value: "_548.PittingFactorCalculationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Rating.Iso10300.PittingFactorCalculationMethod"
        )
        pythonnet_property_set(
            self.wrapped, "BevelPittingFactorCalculationMethod", value
        )

    @property
    @exception_bridge
    def hypoid_gear_rating_method(self: "Self") -> "_554.HypoidRatingMethod":
        """mastapy.gears.rating.hypoid.HypoidRatingMethod"""
        temp = pythonnet_property_get(self.wrapped, "HypoidGearRatingMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Hypoid.HypoidRatingMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.hypoid._554", "HypoidRatingMethod"
        )(value)

    @hypoid_gear_rating_method.setter
    @exception_bridge
    @enforce_parameter_types
    def hypoid_gear_rating_method(
        self: "Self", value: "_554.HypoidRatingMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Rating.Hypoid.HypoidRatingMethod"
        )
        pythonnet_property_set(self.wrapped, "HypoidGearRatingMethod", value)

    @property
    @exception_bridge
    def hypoid_general_load_factors_k_method(
        self: "Self",
    ) -> "_533.GeneralLoadFactorCalculationMethod":
        """mastapy.gears.rating.isoGeneralLoadFactorCalculationMethod"""
        temp = pythonnet_property_get(self.wrapped, "HypoidGeneralLoadFactorsKMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Iso10300.GeneralLoadFactorCalculationMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._533", "GeneralLoadFactorCalculationMethod"
        )(value)

    @hypoid_general_load_factors_k_method.setter
    @exception_bridge
    @enforce_parameter_types
    def hypoid_general_load_factors_k_method(
        self: "Self", value: "_533.GeneralLoadFactorCalculationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.Rating.Iso10300.GeneralLoadFactorCalculationMethod",
        )
        pythonnet_property_set(self.wrapped, "HypoidGeneralLoadFactorsKMethod", value)

    @property
    @exception_bridge
    def hypoid_pitting_factor_calculation_method(
        self: "Self",
    ) -> "_548.PittingFactorCalculationMethod":
        """mastapy.gears.rating.isoPittingFactorCalculationMethod"""
        temp = pythonnet_property_get(
            self.wrapped, "HypoidPittingFactorCalculationMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Iso10300.PittingFactorCalculationMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._548", "PittingFactorCalculationMethod"
        )(value)

    @hypoid_pitting_factor_calculation_method.setter
    @exception_bridge
    @enforce_parameter_types
    def hypoid_pitting_factor_calculation_method(
        self: "Self", value: "_548.PittingFactorCalculationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Rating.Iso10300.PittingFactorCalculationMethod"
        )
        pythonnet_property_set(
            self.wrapped, "HypoidPittingFactorCalculationMethod", value
        )

    @property
    @exception_bridge
    def iso_rating_method_for_bevel_gears(self: "Self") -> "_541.ISO10300RatingMethod":
        """mastapy.gears.rating.isoISO10300RatingMethod"""
        temp = pythonnet_property_get(self.wrapped, "ISORatingMethodForBevelGears")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Iso10300.ISO10300RatingMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._541", "ISO10300RatingMethod"
        )(value)

    @iso_rating_method_for_bevel_gears.setter
    @exception_bridge
    @enforce_parameter_types
    def iso_rating_method_for_bevel_gears(
        self: "Self", value: "_541.ISO10300RatingMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Rating.Iso10300.ISO10300RatingMethod"
        )
        pythonnet_property_set(self.wrapped, "ISORatingMethodForBevelGears", value)

    @property
    @exception_bridge
    def iso_rating_method_for_hypoid_gears(self: "Self") -> "_541.ISO10300RatingMethod":
        """mastapy.gears.rating.isoISO10300RatingMethod"""
        temp = pythonnet_property_get(self.wrapped, "ISORatingMethodForHypoidGears")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Iso10300.ISO10300RatingMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating._541", "ISO10300RatingMethod"
        )(value)

    @iso_rating_method_for_hypoid_gears.setter
    @exception_bridge
    @enforce_parameter_types
    def iso_rating_method_for_hypoid_gears(
        self: "Self", value: "_541.ISO10300RatingMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Rating.Iso10300.ISO10300RatingMethod"
        )
        pythonnet_property_set(self.wrapped, "ISORatingMethodForHypoidGears", value)

    @property
    @exception_bridge
    def include_mesh_node_misalignments_in_default_report(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "IncludeMeshNodeMisalignmentsInDefaultReport"
        )

        if temp is None:
            return False

        return temp

    @include_mesh_node_misalignments_in_default_report.setter
    @exception_bridge
    @enforce_parameter_types
    def include_mesh_node_misalignments_in_default_report(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeMeshNodeMisalignmentsInDefaultReport",
            bool(value) if value is not None else False,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_BevelHypoidGearRatingSettingsItem":
        """Cast to another type.

        Returns:
            _Cast_BevelHypoidGearRatingSettingsItem
        """
        return _Cast_BevelHypoidGearRatingSettingsItem(self)



"""PlanetaryDetail"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import conversion, utility

_PLANETARY_DETAIL = python_net_import("SMT.MastaAPI.Gears", "PlanetaryDetail")

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears import _448

    Self = TypeVar("Self", bound="PlanetaryDetail")
    CastSelf = TypeVar("CastSelf", bound="PlanetaryDetail._Cast_PlanetaryDetail")


__docformat__ = "restructuredtext en"
__all__ = ("PlanetaryDetail",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlanetaryDetail:
    """Special nested class for casting PlanetaryDetail to subclasses."""

    __parent__: "PlanetaryDetail"

    @property
    def planetary_detail(self: "CastSelf") -> "PlanetaryDetail":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlanetaryDetail(_0.APIBase):
    """PlanetaryDetail

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PLANETARY_DETAIL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def first_planet_angle(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "FirstPlanetAngle")

        if temp is None:
            return 0.0

        return temp

    @first_planet_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def first_planet_angle(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "FirstPlanetAngle", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def number_of_planets(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfPlanets")

        if temp is None:
            return 0

        return temp

    @number_of_planets.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_planets(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfPlanets", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def planet_diameter(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PlanetDiameter")

        if temp is None:
            return 0.0

        return temp

    @planet_diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def planet_diameter(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "PlanetDiameter", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def regularly_spaced_planets(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "RegularlySpacedPlanets")

        if temp is None:
            return False

        return temp

    @regularly_spaced_planets.setter
    @exception_bridge
    @enforce_parameter_types
    def regularly_spaced_planets(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "RegularlySpacedPlanets",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def planet_delta_angles(self: "Self") -> "List[_448.NamedPlanetAngle]":
        """List[mastapy.gears.NamedPlanetAngle]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PlanetDeltaAngles")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_PlanetaryDetail":
        """Cast to another type.

        Returns:
            _Cast_PlanetaryDetail
        """
        return _Cast_PlanetaryDetail(self)



"""BevelDifferentialGearCompoundMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
    _5886,
)

_BEVEL_DIFFERENTIAL_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound",
    "BevelDifferentialGearCompoundMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5727
    from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
        _5874,
        _5884,
        _5885,
        _5895,
        _5902,
        _5928,
        _5949,
        _5951,
    )
    from mastapy._private.system_model.part_model.gears import _2797

    Self = TypeVar(
        "Self", bound="BevelDifferentialGearCompoundMultibodyDynamicsAnalysis"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="BevelDifferentialGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialGearCompoundMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BevelDifferentialGearCompoundMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BevelDifferentialGearCompoundMultibodyDynamicsAnalysis:
    """Special nested class for casting BevelDifferentialGearCompoundMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "BevelDifferentialGearCompoundMultibodyDynamicsAnalysis"

    @property
    def bevel_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5886.BevelGearCompoundMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5886.BevelGearCompoundMultibodyDynamicsAnalysis)

    @property
    def agma_gleason_conical_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5874.AGMAGleasonConicalGearCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5874,
        )

        return self.__parent__._cast(
            _5874.AGMAGleasonConicalGearCompoundMultibodyDynamicsAnalysis
        )

    @property
    def conical_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5902.ConicalGearCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5902,
        )

        return self.__parent__._cast(_5902.ConicalGearCompoundMultibodyDynamicsAnalysis)

    @property
    def gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5928.GearCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5928,
        )

        return self.__parent__._cast(_5928.GearCompoundMultibodyDynamicsAnalysis)

    @property
    def mountable_component_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5949.MountableComponentCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5949,
        )

        return self.__parent__._cast(
            _5949.MountableComponentCompoundMultibodyDynamicsAnalysis
        )

    @property
    def component_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5895.ComponentCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5895,
        )

        return self.__parent__._cast(_5895.ComponentCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5951.PartCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5951,
        )

        return self.__parent__._cast(_5951.PartCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def bevel_differential_planet_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5884.BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5884,
        )

        return self.__parent__._cast(
            _5884.BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis
        )

    @property
    def bevel_differential_sun_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5885.BevelDifferentialSunGearCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5885,
        )

        return self.__parent__._cast(
            _5885.BevelDifferentialSunGearCompoundMultibodyDynamicsAnalysis
        )

    @property
    def bevel_differential_gear_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "BevelDifferentialGearCompoundMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BevelDifferentialGearCompoundMultibodyDynamicsAnalysis(
    _5886.BevelGearCompoundMultibodyDynamicsAnalysis
):
    """BevelDifferentialGearCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _BEVEL_DIFFERENTIAL_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2797.BevelDifferentialGear":
        """mastapy.system_model.part_model.gears.BevelDifferentialGear

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def component_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5727.BevelDifferentialGearMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.BevelDifferentialGearMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def component_analysis_cases(
        self: "Self",
    ) -> "List[_5727.BevelDifferentialGearMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.BevelDifferentialGearMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_BevelDifferentialGearCompoundMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_BevelDifferentialGearCompoundMultibodyDynamicsAnalysis
        """
        return _Cast_BevelDifferentialGearCompoundMultibodyDynamicsAnalysis(self)



"""DesignEntityId"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_DESIGN_ENTITY_ID = python_net_import("SMT.MastaAPI.SystemModel", "DesignEntityId")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="DesignEntityId")
    CastSelf = TypeVar("CastSelf", bound="DesignEntityId._Cast_DesignEntityId")


__docformat__ = "restructuredtext en"
__all__ = ("DesignEntityId",)


class DesignEntityId(Enum):
    """DesignEntityId

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _DESIGN_ENTITY_ID

    ASSEMBLY = 0
    ROLLING_BEARING = 1
    JOURNAL_BEARING = 2
    BEARING = 3
    SHAFT = 4
    PLANET_SHAFT = 5
    CYLINDRICAL_GEAR = 6
    CYLINDRICAL_RING_GEAR = 7
    CYLINDRICAL_SUN_GEAR = 8
    CYLINDRICAL_PLANET_GEAR = 9
    CYLINDRICAL_GEAR_PAIR = 10
    CYLINDRICAL_GEAR_SET = 11
    CYLINDRICAL_PLANETARY_GEAR_SET = 12
    STRAIGHT_BEVEL_DIFFERENTIAL_GEAR_SET = 13
    SPIRAL_BEVEL_DIFFERENTIAL_GEAR_SET = 14
    ZEROL_BEVEL_DIFFERENTIAL_GEAR_SET = 15
    DATUM = 16
    MICROPHONE_ARRAY = 17
    MICROPHONE = 18
    SPLINE = 19
    CYLINDRICAL_PLANET_CARRIER = 20
    BEVEL_DIFFERENTIAL_PLANET_CARRIER = 21
    SHAFTHUB_CONNECTION = 22
    EXTERNAL_3D_CAD_MODEL = 23
    EXTERNAL_2D_CAD_MODEL = 24
    FE_PART = 25
    DISABLED_FE_PART = 26
    CONICAL_GEAR_SET = 27
    CONICAL_GEAR = 28
    MEASUREMENT_POINT = 29
    WORM_GEAR = 30
    WORM_WHEEL = 31
    WORM_GEAR_SET = 32
    SPIRAL_BEVEL_GEAR = 33
    SPIRAL_BEVEL_GEAR_SET = 34
    STRAIGHT_BEVEL_GEAR = 35
    STRAIGHT_BEVEL_GEAR_SET = 36
    HYPOID_GEAR = 37
    HYPOID_GEAR_SET = 38
    KLINGELNBERG_CYCLOPALLOID_SPIRAL_BEVEL_GEAR = 39
    KLINGELNBERG_CYCLOPALLOID_SPIRAL_BEVEL_GEAR_SET = 40
    KLINGELNBERG_CYCLOPALLOID_HYPOID_GEAR = 41
    KLINGELNBERG_CYCLOPALLOID_HYPOID_GEAR_SET = 42
    ZEROL_GEAR = 43
    ZEROL_GEAR_SET = 44
    POWER_LOAD = 45
    POINT_LOAD = 46
    SPRING_DAMPER = 47
    OIL_SEAL = 48
    MASS_DISC = 49
    BOLT = 50
    BOLTED_JOINT = 51
    ROLLING_RING = 52
    UNBALANCED_MASS = 53
    FLEXIBLE_PIN_ASSEMBLY = 54
    FLEXIBLE_PIN = 55
    BELT_DRIVE = 56
    PULLEY = 57
    TORQUE_CONVERTER = 58
    CVT = 59
    CONCEPT_COUPLING = 60
    CLUTCH = 61
    CONNECTION = 62
    SYNCHRONISER = 63
    CONCEPT_GEAR = 64
    CONCEPT_GEAR_SET = 65
    SUPERCHARGER_ROTOR = 66
    SUPERCHARGER_ROTOR_SET = 67
    FACE_GEAR_PINION = 68
    FACE_GEAR_WHEEL = 69
    FACE_GEAR_SET = 70
    PARTTOPART_SHEAR_COUPLING = 71
    CYCLOIDAL_DISC = 72
    RING_PINS = 73
    CYCLOIDAL_ASSEMBLY = 74


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


DesignEntityId.__setattr__ = __enum_setattr
DesignEntityId.__delattr__ = __enum_delattr



"""CustomRow"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import utility
from mastapy._private.utility.report import _2002

_CUSTOM_ROW = python_net_import("SMT.MastaAPI.Utility.Report", "CustomRow")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.utility.report import _1973, _2016

    Self = TypeVar("Self", bound="CustomRow")
    CastSelf = TypeVar("CastSelf", bound="CustomRow._Cast_CustomRow")


__docformat__ = "restructuredtext en"
__all__ = ("CustomRow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CustomRow:
    """Special nested class for casting CustomRow to subclasses."""

    __parent__: "CustomRow"

    @property
    def custom_report_property_item(
        self: "CastSelf",
    ) -> "_2002.CustomReportPropertyItem":
        return self.__parent__._cast(_2002.CustomReportPropertyItem)

    @property
    def blank_row(self: "CastSelf") -> "_1973.BlankRow":
        from mastapy._private.utility.report import _1973

        return self.__parent__._cast(_1973.BlankRow)

    @property
    def user_text_row(self: "CastSelf") -> "_2016.UserTextRow":
        from mastapy._private.utility.report import _2016

        return self.__parent__._cast(_2016.UserTextRow)

    @property
    def custom_row(self: "CastSelf") -> "CustomRow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CustomRow(_2002.CustomReportPropertyItem):
    """CustomRow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CUSTOM_ROW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def calculate_sum_of_values(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "CalculateSumOfValues")

        if temp is None:
            return False

        return temp

    @calculate_sum_of_values.setter
    @exception_bridge
    @enforce_parameter_types
    def calculate_sum_of_values(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "CalculateSumOfValues",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def count_values(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "CountValues")

        if temp is None:
            return False

        return temp

    @count_values.setter
    @exception_bridge
    @enforce_parameter_types
    def count_values(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "CountValues", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def is_minor_value(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IsMinorValue")

        if temp is None:
            return False

        return temp

    @is_minor_value.setter
    @exception_bridge
    @enforce_parameter_types
    def is_minor_value(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "IsMinorValue", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def overridden_property_name(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "OverriddenPropertyName")

        if temp is None:
            return ""

        return temp

    @overridden_property_name.setter
    @exception_bridge
    @enforce_parameter_types
    def overridden_property_name(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OverriddenPropertyName",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def override_property_name(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "OverridePropertyName")

        if temp is None:
            return False

        return temp

    @override_property_name.setter
    @exception_bridge
    @enforce_parameter_types
    def override_property_name(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OverridePropertyName",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_maximum_of_absolute_values(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowMaximumOfAbsoluteValues")

        if temp is None:
            return False

        return temp

    @show_maximum_of_absolute_values.setter
    @exception_bridge
    @enforce_parameter_types
    def show_maximum_of_absolute_values(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowMaximumOfAbsoluteValues",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_maximum_of_values(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowMaximumOfValues")

        if temp is None:
            return False

        return temp

    @show_maximum_of_values.setter
    @exception_bridge
    @enforce_parameter_types
    def show_maximum_of_values(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowMaximumOfValues",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_minimum_of_values(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowMinimumOfValues")

        if temp is None:
            return False

        return temp

    @show_minimum_of_values.setter
    @exception_bridge
    @enforce_parameter_types
    def show_minimum_of_values(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowMinimumOfValues",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_as_information(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowAsInformation")

        if temp is None:
            return False

        return temp

    @show_as_information.setter
    @exception_bridge
    @enforce_parameter_types
    def show_as_information(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowAsInformation",
            bool(value) if value is not None else False,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_CustomRow":
        """Cast to another type.

        Returns:
            _Cast_CustomRow
        """
        return _Cast_CustomRow(self)



"""AGMAGleasonConicalGearMeshCompoundPowerFlow"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
    _4516,
)

_AGMA_GLEASON_CONICAL_GEAR_MESH_COMPOUND_POWER_FLOW = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows.Compound",
    "AGMAGleasonConicalGearMeshCompoundPowerFlow",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7937,
        _7941,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows import _4350
    from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
        _4495,
        _4500,
        _4518,
        _4542,
        _4546,
        _4548,
        _4585,
        _4591,
        _4594,
        _4612,
    )

    Self = TypeVar("Self", bound="AGMAGleasonConicalGearMeshCompoundPowerFlow")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AGMAGleasonConicalGearMeshCompoundPowerFlow._Cast_AGMAGleasonConicalGearMeshCompoundPowerFlow",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AGMAGleasonConicalGearMeshCompoundPowerFlow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AGMAGleasonConicalGearMeshCompoundPowerFlow:
    """Special nested class for casting AGMAGleasonConicalGearMeshCompoundPowerFlow to subclasses."""

    __parent__: "AGMAGleasonConicalGearMeshCompoundPowerFlow"

    @property
    def conical_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4516.ConicalGearMeshCompoundPowerFlow":
        return self.__parent__._cast(_4516.ConicalGearMeshCompoundPowerFlow)

    @property
    def gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4542.GearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4542,
        )

        return self.__parent__._cast(_4542.GearMeshCompoundPowerFlow)

    @property
    def inter_mountable_component_connection_compound_power_flow(
        self: "CastSelf",
    ) -> "_4548.InterMountableComponentConnectionCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4548,
        )

        return self.__parent__._cast(
            _4548.InterMountableComponentConnectionCompoundPowerFlow
        )

    @property
    def connection_compound_power_flow(
        self: "CastSelf",
    ) -> "_4518.ConnectionCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4518,
        )

        return self.__parent__._cast(_4518.ConnectionCompoundPowerFlow)

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7937.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7937,
        )

        return self.__parent__._cast(_7937.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def bevel_differential_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4495.BevelDifferentialGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4495,
        )

        return self.__parent__._cast(_4495.BevelDifferentialGearMeshCompoundPowerFlow)

    @property
    def bevel_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4500.BevelGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4500,
        )

        return self.__parent__._cast(_4500.BevelGearMeshCompoundPowerFlow)

    @property
    def hypoid_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4546.HypoidGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4546,
        )

        return self.__parent__._cast(_4546.HypoidGearMeshCompoundPowerFlow)

    @property
    def spiral_bevel_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4585.SpiralBevelGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4585,
        )

        return self.__parent__._cast(_4585.SpiralBevelGearMeshCompoundPowerFlow)

    @property
    def straight_bevel_diff_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4591.StraightBevelDiffGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4591,
        )

        return self.__parent__._cast(_4591.StraightBevelDiffGearMeshCompoundPowerFlow)

    @property
    def straight_bevel_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4594.StraightBevelGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4594,
        )

        return self.__parent__._cast(_4594.StraightBevelGearMeshCompoundPowerFlow)

    @property
    def zerol_bevel_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "_4612.ZerolBevelGearMeshCompoundPowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
            _4612,
        )

        return self.__parent__._cast(_4612.ZerolBevelGearMeshCompoundPowerFlow)

    @property
    def agma_gleason_conical_gear_mesh_compound_power_flow(
        self: "CastSelf",
    ) -> "AGMAGleasonConicalGearMeshCompoundPowerFlow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AGMAGleasonConicalGearMeshCompoundPowerFlow(
    _4516.ConicalGearMeshCompoundPowerFlow
):
    """AGMAGleasonConicalGearMeshCompoundPowerFlow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _AGMA_GLEASON_CONICAL_GEAR_MESH_COMPOUND_POWER_FLOW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_4350.AGMAGleasonConicalGearMeshPowerFlow]":
        """List[mastapy.system_model.analyses_and_results.power_flows.AGMAGleasonConicalGearMeshPowerFlow]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4350.AGMAGleasonConicalGearMeshPowerFlow]":
        """List[mastapy.system_model.analyses_and_results.power_flows.AGMAGleasonConicalGearMeshPowerFlow]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AGMAGleasonConicalGearMeshCompoundPowerFlow":
        """Cast to another type.

        Returns:
            _Cast_AGMAGleasonConicalGearMeshCompoundPowerFlow
        """
        return _Cast_AGMAGleasonConicalGearMeshCompoundPowerFlow(self)



"""HobbingProcessSimulationViewModel"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
    _799,
    _813,
)

_HOBBING_PROCESS_SIMULATION_VIEW_MODEL = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "HobbingProcessSimulationViewModel",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical import _754

    Self = TypeVar("Self", bound="HobbingProcessSimulationViewModel")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HobbingProcessSimulationViewModel._Cast_HobbingProcessSimulationViewModel",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HobbingProcessSimulationViewModel",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HobbingProcessSimulationViewModel:
    """Special nested class for casting HobbingProcessSimulationViewModel to subclasses."""

    __parent__: "HobbingProcessSimulationViewModel"

    @property
    def process_simulation_view_model(
        self: "CastSelf",
    ) -> "_813.ProcessSimulationViewModel":
        return self.__parent__._cast(_813.ProcessSimulationViewModel)

    @property
    def gear_manufacturing_configuration_view_model(
        self: "CastSelf",
    ) -> "_754.GearManufacturingConfigurationViewModel":
        from mastapy._private.gears.manufacturing.cylindrical import _754

        return self.__parent__._cast(_754.GearManufacturingConfigurationViewModel)

    @property
    def hobbing_process_simulation_view_model(
        self: "CastSelf",
    ) -> "HobbingProcessSimulationViewModel":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class HobbingProcessSimulationViewModel(
    _813.ProcessSimulationViewModel[_799.HobbingProcessSimulationNew]
):
    """HobbingProcessSimulationViewModel

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HOBBING_PROCESS_SIMULATION_VIEW_MODEL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_HobbingProcessSimulationViewModel":
        """Cast to another type.

        Returns:
            _Cast_HobbingProcessSimulationViewModel
        """
        return _Cast_HobbingProcessSimulationViewModel(self)



"""ConvectionFaceBase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import _226

_CONVECTION_FACE_BASE = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.LumpedParameterThermalAnalysis", "ConvectionFaceBase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
        _182,
        _190,
        _192,
        _208,
        _210,
        _213,
        _230,
    )

    Self = TypeVar("Self", bound="ConvectionFaceBase")
    CastSelf = TypeVar("CastSelf", bound="ConvectionFaceBase._Cast_ConvectionFaceBase")


__docformat__ = "restructuredtext en"
__all__ = ("ConvectionFaceBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConvectionFaceBase:
    """Special nested class for casting ConvectionFaceBase to subclasses."""

    __parent__: "ConvectionFaceBase"

    @property
    def thermal_face(self: "CastSelf") -> "_226.ThermalFace":
        return self.__parent__._cast(_226.ThermalFace)

    @property
    def air_gap_convection_face(self: "CastSelf") -> "_182.AirGapConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _182,
        )

        return self.__parent__._cast(_182.AirGapConvectionFace)

    @property
    def channel_convection_face(self: "CastSelf") -> "_190.ChannelConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _190,
        )

        return self.__parent__._cast(_190.ChannelConvectionFace)

    @property
    def convection_face(self: "CastSelf") -> "_192.ConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _192,
        )

        return self.__parent__._cast(_192.ConvectionFace)

    @property
    def fluid_channel_cuboid_convection_face(
        self: "CastSelf",
    ) -> "_208.FluidChannelCuboidConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _208,
        )

        return self.__parent__._cast(_208.FluidChannelCuboidConvectionFace)

    @property
    def fluid_channel_cylindrical_radial_convection_face(
        self: "CastSelf",
    ) -> "_210.FluidChannelCylindricalRadialConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _210,
        )

        return self.__parent__._cast(_210.FluidChannelCylindricalRadialConvectionFace)

    @property
    def generic_convection_face(self: "CastSelf") -> "_213.GenericConvectionFace":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _213,
        )

        return self.__parent__._cast(_213.GenericConvectionFace)

    @property
    def convection_face_base(self: "CastSelf") -> "ConvectionFaceBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConvectionFaceBase(_226.ThermalFace):
    """ConvectionFaceBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONVECTION_FACE_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def user_defined_heat_transfer_coefficient(
        self: "Self",
    ) -> "_230.UserDefinedHeatTransferCoefficient":
        """mastapy.nodal_analysis.lumped_parameter_thermal_analysis.UserDefinedHeatTransferCoefficient

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "UserDefinedHeatTransferCoefficient"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ConvectionFaceBase":
        """Cast to another type.

        Returns:
            _Cast_ConvectionFaceBase
        """
        return _Cast_ConvectionFaceBase(self)



"""GearSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.system_deflections import _3077

_GEAR_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections",
    "GearSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.math_utility.measured_vectors import _1777
    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7945,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows import _4408
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2984,
        _2996,
        _2997,
        _2998,
        _3001,
        _3008,
        _3015,
        _3019,
        _3038,
        _3039,
        _3040,
        _3043,
        _3049,
        _3053,
        _3058,
        _3063,
        _3066,
        _3069,
        _3080,
        _3104,
        _3110,
        _3113,
        _3114,
        _3115,
        _3134,
        _3137,
    )
    from mastapy._private.system_model.part_model.gears import _2812

    Self = TypeVar("Self", bound="GearSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf", bound="GearSystemDeflection._Cast_GearSystemDeflection"
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearSystemDeflection:
    """Special nested class for casting GearSystemDeflection to subclasses."""

    __parent__: "GearSystemDeflection"

    @property
    def mountable_component_system_deflection(
        self: "CastSelf",
    ) -> "_3077.MountableComponentSystemDeflection":
        return self.__parent__._cast(_3077.MountableComponentSystemDeflection)

    @property
    def component_system_deflection(
        self: "CastSelf",
    ) -> "_3008.ComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3008,
        )

        return self.__parent__._cast(_3008.ComponentSystemDeflection)

    @property
    def part_system_deflection(self: "CastSelf") -> "_3080.PartSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3080,
        )

        return self.__parent__._cast(_3080.PartSystemDeflection)

    @property
    def part_fe_analysis(self: "CastSelf") -> "_7945.PartFEAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7945,
        )

        return self.__parent__._cast(_7945.PartFEAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2984.AGMAGleasonConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2984,
        )

        return self.__parent__._cast(_2984.AGMAGleasonConicalGearSystemDeflection)

    @property
    def bevel_differential_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2996.BevelDifferentialGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2996,
        )

        return self.__parent__._cast(_2996.BevelDifferentialGearSystemDeflection)

    @property
    def bevel_differential_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2997.BevelDifferentialPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2997,
        )

        return self.__parent__._cast(_2997.BevelDifferentialPlanetGearSystemDeflection)

    @property
    def bevel_differential_sun_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2998.BevelDifferentialSunGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2998,
        )

        return self.__parent__._cast(_2998.BevelDifferentialSunGearSystemDeflection)

    @property
    def bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3001.BevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3001,
        )

        return self.__parent__._cast(_3001.BevelGearSystemDeflection)

    @property
    def concept_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3015.ConceptGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3015,
        )

        return self.__parent__._cast(_3015.ConceptGearSystemDeflection)

    @property
    def conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3019.ConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3019,
        )

        return self.__parent__._cast(_3019.ConicalGearSystemDeflection)

    @property
    def cylindrical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3038.CylindricalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3038,
        )

        return self.__parent__._cast(_3038.CylindricalGearSystemDeflection)

    @property
    def cylindrical_gear_system_deflection_timestep(
        self: "CastSelf",
    ) -> "_3039.CylindricalGearSystemDeflectionTimestep":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3039,
        )

        return self.__parent__._cast(_3039.CylindricalGearSystemDeflectionTimestep)

    @property
    def cylindrical_gear_system_deflection_with_ltca_results(
        self: "CastSelf",
    ) -> "_3040.CylindricalGearSystemDeflectionWithLTCAResults":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3040,
        )

        return self.__parent__._cast(
            _3040.CylindricalGearSystemDeflectionWithLTCAResults
        )

    @property
    def cylindrical_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3043.CylindricalPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3043,
        )

        return self.__parent__._cast(_3043.CylindricalPlanetGearSystemDeflection)

    @property
    def face_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3049.FaceGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3049,
        )

        return self.__parent__._cast(_3049.FaceGearSystemDeflection)

    @property
    def hypoid_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3058.HypoidGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3058,
        )

        return self.__parent__._cast(_3058.HypoidGearSystemDeflection)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3063.KlingelnbergCycloPalloidConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3063,
        )

        return self.__parent__._cast(
            _3063.KlingelnbergCycloPalloidConicalGearSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3066.KlingelnbergCycloPalloidHypoidGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3066,
        )

        return self.__parent__._cast(
            _3066.KlingelnbergCycloPalloidHypoidGearSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3069.KlingelnbergCycloPalloidSpiralBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3069,
        )

        return self.__parent__._cast(
            _3069.KlingelnbergCycloPalloidSpiralBevelGearSystemDeflection
        )

    @property
    def spiral_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3104.SpiralBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3104,
        )

        return self.__parent__._cast(_3104.SpiralBevelGearSystemDeflection)

    @property
    def straight_bevel_diff_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3110.StraightBevelDiffGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3110,
        )

        return self.__parent__._cast(_3110.StraightBevelDiffGearSystemDeflection)

    @property
    def straight_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3113.StraightBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3113,
        )

        return self.__parent__._cast(_3113.StraightBevelGearSystemDeflection)

    @property
    def straight_bevel_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3114.StraightBevelPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3114,
        )

        return self.__parent__._cast(_3114.StraightBevelPlanetGearSystemDeflection)

    @property
    def straight_bevel_sun_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3115.StraightBevelSunGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3115,
        )

        return self.__parent__._cast(_3115.StraightBevelSunGearSystemDeflection)

    @property
    def worm_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3134.WormGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3134,
        )

        return self.__parent__._cast(_3134.WormGearSystemDeflection)

    @property
    def zerol_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_3137.ZerolBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3137,
        )

        return self.__parent__._cast(_3137.ZerolBevelGearSystemDeflection)

    @property
    def gear_system_deflection(self: "CastSelf") -> "GearSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearSystemDeflection(_3077.MountableComponentSystemDeflection):
    """GearSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def is_loaded(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsLoaded")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2812.Gear":
        """mastapy.system_model.part_model.gears.Gear

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def mesh_point_results_in_wcs(
        self: "Self",
    ) -> "List[_1777.ForceAndDisplacementResults]":
        """List[mastapy.math_utility.measured_vectors.ForceAndDisplacementResults]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshPointResultsInWCS")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_set(self: "Self") -> "_3053.GearSetSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.GearSetSystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearSet")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def power_flow_results(self: "Self") -> "_4408.GearPowerFlow":
        """mastapy.system_model.analyses_and_results.power_flows.GearPowerFlow

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PowerFlowResults")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_GearSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_GearSystemDeflection
        """
        return _Cast_GearSystemDeflection(self)



"""ScriptCoefficientOfFrictionCalculator"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.gears.materials import _713

_SCRIPT_COEFFICIENT_OF_FRICTION_CALCULATOR = python_net_import(
    "SMT.MastaAPI.Gears.Materials", "ScriptCoefficientOfFrictionCalculator"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.materials import _703

    Self = TypeVar("Self", bound="ScriptCoefficientOfFrictionCalculator")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ScriptCoefficientOfFrictionCalculator._Cast_ScriptCoefficientOfFrictionCalculator",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ScriptCoefficientOfFrictionCalculator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ScriptCoefficientOfFrictionCalculator:
    """Special nested class for casting ScriptCoefficientOfFrictionCalculator to subclasses."""

    __parent__: "ScriptCoefficientOfFrictionCalculator"

    @property
    def instantaneous_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_713.InstantaneousCoefficientOfFrictionCalculator":
        return self.__parent__._cast(_713.InstantaneousCoefficientOfFrictionCalculator)

    @property
    def coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_703.CoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _703

        return self.__parent__._cast(_703.CoefficientOfFrictionCalculator)

    @property
    def script_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "ScriptCoefficientOfFrictionCalculator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ScriptCoefficientOfFrictionCalculator(
    _713.InstantaneousCoefficientOfFrictionCalculator
):
    """ScriptCoefficientOfFrictionCalculator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SCRIPT_COEFFICIENT_OF_FRICTION_CALCULATOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def combined_radius_of_curvature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CombinedRadiusOfCurvature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def contact_length(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ContactLength")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def dynamic_viscosity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DynamicViscosity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def entrainment_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "EntrainmentVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def internal_external_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InternalExternalFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def kinematic_viscosity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "KinematicViscosity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normal_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NormalLoad")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def pinion_tooth_passing_speed(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PinionToothPassingSpeed")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def roll_distance(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RollDistance")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def sliding_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SlidingVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def wheel_tooth_passing_speed(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "WheelToothPassingSpeed")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_ScriptCoefficientOfFrictionCalculator":
        """Cast to another type.

        Returns:
            _Cast_ScriptCoefficientOfFrictionCalculator
        """
        return _Cast_ScriptCoefficientOfFrictionCalculator(self)



"""BacklashSpecification"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.gear_designs.cylindrical import _1202

_BACKLASH_SPECIFICATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "BacklashSpecification"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical import _1169, _1190

    Self = TypeVar("Self", bound="BacklashSpecification")
    CastSelf = TypeVar(
        "CastSelf", bound="BacklashSpecification._Cast_BacklashSpecification"
    )


__docformat__ = "restructuredtext en"
__all__ = ("BacklashSpecification",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BacklashSpecification:
    """Special nested class for casting BacklashSpecification to subclasses."""

    __parent__: "BacklashSpecification"

    @property
    def relative_values_specification(
        self: "CastSelf",
    ) -> "_1202.RelativeValuesSpecification":
        pass

        return self.__parent__._cast(_1202.RelativeValuesSpecification)

    @property
    def backlash_specification(self: "CastSelf") -> "BacklashSpecification":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BacklashSpecification(_1202.RelativeValuesSpecification["BacklashSpecification"]):
    """BacklashSpecification

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BACKLASH_SPECIFICATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def left_flank(self: "Self") -> "_1190.LinearBacklashSpecification":
        """mastapy.gears.gear_designs.cylindrical.LinearBacklashSpecification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeftFlank")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def right_flank(self: "Self") -> "_1190.LinearBacklashSpecification":
        """mastapy.gears.gear_designs.cylindrical.LinearBacklashSpecification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RightFlank")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def angular_backlash(self: "Self") -> "List[_1169.CylindricalMeshAngularBacklash]":
        """List[mastapy.gears.gear_designs.cylindrical.CylindricalMeshAngularBacklash]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AngularBacklash")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def flanks(self: "Self") -> "List[_1190.LinearBacklashSpecification]":
        """List[mastapy.gears.gear_designs.cylindrical.LinearBacklashSpecification]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Flanks")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def both_flanks(self: "Self") -> "_1190.LinearBacklashSpecification":
        """mastapy.gears.gear_designs.cylindrical.LinearBacklashSpecification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BothFlanks")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_BacklashSpecification":
        """Cast to another type.

        Returns:
            _Cast_BacklashSpecification
        """
        return _Cast_BacklashSpecification(self)
